@@ -16,10 +16,12 @@
 //! The method [Database::run] (or alternatively [Database::run_timed]) is called to execute an SQL query.
 //! This takes a [Transaction] parameter which accumulates SELECT results and which also has methods
 //! for accessing input parameters and controlling output. Custom builtin functions implement [CExp]
-//! and have access to the transaction via an [EvalEnv] parameter, which can be downcast if necessary.   
+//! and have access to the transaction via an [EvalEnv] parameter, which can be downcast if necessary. 
+//!
+//! It is also possible to access the table data directly, see email_loop in example (b).   
 //!
 //!# Examples
-//! (a) Simple single-threaded web server using SimpleFileStorage as underlying storage.s
+//! (a) Simple single-threaded web server using SimpleFileStorage as underlying storage.
 //! ```
 //! use rustdb::{standard_builtins, AccessPagedData, Database, SharedPagedData, SimpleFileStorage, WebTransaction, INITSQL, BuiltinMap};
 //! use std::net::TcpListener;
@@ -476,6 +478,16 @@ GO
         self.file.save(op)
     }
 
+    #[cfg(not(feature = "max"))]
+    /// Get the named table.
+    pub(crate) fn get_table(self: &DB, name: &ObjRef) -> Option<TablePtr> {
+        if let Some(t) = self.tables.borrow().get(name) {
+            return Some(t.clone());
+        }
+        sys::get_table(self, name)
+    }
+
+    #[cfg(feature = "max")]
     /// Get the named table.
     pub fn get_table(self: &DB, name: &ObjRef) -> Option<TablePtr> {
         if let Some(t) = self.tables.borrow().get(name) {
@@ -569,7 +581,7 @@ impl TableBuilder {
 }
 
 /// Input/Output message. Query and Response.
-pub trait Transaction {
+pub trait Transaction : Any {
     /// STATUSCODE builtin function. sets the response status code.
     fn status_code(&mut self, _code: i64) {}
 
