@@ -116,12 +116,16 @@ impl Storage for SimpleFileStorage {
     fn write(&self, off: u64, bytes: &[u8]) {
         let mut f = self.file.lock().unwrap();
         f.seek(SeekFrom::Start(off)).unwrap();
-        let _x = f.write(bytes);
+        if let Err(e) = f.write(bytes) {
+            std::panic::panic_any(e);
+        }
     }
 
     fn commit(&self, size: u64) {
         let f = self.file.lock().unwrap();
         f.set_len(size).unwrap();
-        let _err = f.sync_all();
+        if let Err(e) = f.sync_all() {
+            std::panic::panic_any(e);
+        }
     }
 }
